// Copyright (c) 2023 Proton AG
//
// This file is part of Proton Mail Bridge.
//
// Proton Mail Bridge is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Proton Mail Bridge is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Proton Mail Bridge. If not, see <https://www.gnu.org/licenses/>.

import QtQml
import QtQuick
import QtQuick.Layouts
import QtQuick.Controls

import Proton
import Notifications

Item {
    id: root

    property ColorScheme colorScheme
    property var notifications
    property var mainWindow

    property int notificationWhitelist: NotificationFilter.FilterConsts.All
    property int notificationBlacklist: NotificationFilter.FilterConsts.None

    NotificationFilter {
        id: bannerNotificationFilter

        source: root.notifications.all
        blacklist: Notifications.Group.Dialogs
    }

    Banner {
        colorScheme: root.colorScheme
        notification: bannerNotificationFilter.topmost
        mainWindow: root.mainWindow
    }

    NotificationDialog {
        colorScheme: root.colorScheme
        notification: root.notifications.updateManualReady

        Switch {
            id:autoUpdate
            colorScheme: root.colorScheme
            text: qsTr("Update automatically in the future")
            checked: Backend.isAutomaticUpdateOn
            onClicked: Backend.toggleAutomaticUpdate(autoUpdate.checked)
        }
    }

    NotificationDialog {
        colorScheme: root.colorScheme
        notification: root.notifications.updateForce
    }

    NotificationDialog {
        colorScheme: root.colorScheme
        notification: root.notifications.updateForceError
    }

    NotificationDialog {
        colorScheme: root.colorScheme
        notification: root.notifications.enableBeta
    }

    NotificationDialog {
        colorScheme: root.colorScheme
        notification: root.notifications.cacheUnavailable
    }

    NotificationDialog {
        colorScheme: root.colorScheme
        notification: root.notifications.cacheCantMove
    }

    NotificationDialog {
        colorScheme: root.colorScheme
        notification: root.notifications.diskFull
    }

    NotificationDialog {
        colorScheme: root.colorScheme
        notification: root.notifications.enableSplitMode
    }

    NotificationDialog {
        colorScheme: root.colorScheme
        notification: root.notifications.resetBridge
    }

    NotificationDialog {
        colorScheme: root.colorScheme
        notification: root.notifications.changeAllMailVisibility
    }

    NotificationDialog {
        colorScheme: root.colorScheme
        notification: root.notifications.deleteAccount
    }

    NotificationDialog {
        colorScheme: root.colorScheme
        notification: root.notifications.noKeychain
    }

    NotificationDialog {
        colorScheme: root.colorScheme
        notification: root.notifications.rebuildKeychain
    }

    NotificationDialog {
        colorScheme: root.colorScheme
        notification: root.notifications.apiCertIssue
    }

    NotificationDialog {
        colorScheme: root.colorScheme
        notification: root.notifications.noActiveKeyForRecipient
    }

    NotificationDialog {
        colorScheme: root.colorScheme
        notification: root.notifications.genericError
    }
}
